Struct Probability
pub struct Probability(f64);Expand description
A probability in the range [0.0, 1.0] with a default of 0.5.
Tuple Fields
0: f64Implementations
impl Probability
impl Probability
pub fn new(prob: f64) -> Probability
pub fn new(prob: f64) -> Probability
pub fn with<X>(self, and: X) -> (Probability, X)
pub fn with<X>(self, and: X) -> (Probability, X)
Merges self together with some other argument producing a product
type expected by some implementations of A: Arbitrary in
A::Parameters. This can be more ergonomic to work with and may
help type inference.
pub fn lift<X>(self) -> (Probability, X)where
X: Default,
pub fn lift<X>(self) -> (Probability, X)where
X: Default,
Merges self together with some other argument generated with a
default value producing a product type expected by some
implementations of A: Arbitrary in A::Parameters.
This can be more ergonomic to work with and may help type inference.